@@ -86,8 +86,15 @@ class Controller():
     def get_token(self, data: dict) -> str:
         try:
             resp = requests.post(
-                self.BASE_URL + '/token', data=data
+                self.BASE_URL + '/token', data=data, allow_redirects=False
             )
+            # Handle HTTPS redirect
+            if resp.status_code == 301:
+                https_url = resp.headers['Location']
+                resp = requests.post(https_url, data=data)
+                if resp.status_code == 200:
+                    self.BASE_URL = https_url.replace('/token', '')
+
             resp.raise_for_status()
         except requests.exceptions.HTTPError as err:
             return resp.json()
@@ -508,13 +515,13 @@ class Controller():
 
         # If config exists, we use update command
         if update:
-            subprocess.call([self._settings.fetch_key('python_path'), "-m", "poetry", "-n", "cache", "clear", "pypi", "--all"])
-            subprocess.call([self._settings.fetch_key('python_path'), "-m", "poetry", "env", "use", self._settings.fetch_key('python_path')])
-            subprocess.call([self._settings.fetch_key('python_path'), "-m", "poetry", "update"])
+            subprocess.call([self.python_path, "-m", "poetry", "-n", "cache", "clear", "pypi", "--all"])
+            subprocess.call([self.python_path, "-m", "poetry", "env", "use", self.python_path])
+            subprocess.call([self.python_path, "-m", "poetry", "update"])
         # Or we make the first install
         else:
-            subprocess.call([self._settings.fetch_key('python_path'), "-m", "poetry", "env", "use", self._settings.fetch_key('python_path')])
-            subprocess.call([self._settings.fetch_key('python_path'), "-m", "poetry", "install"])
+            subprocess.call([self.python_path, "-m", "poetry", "env", "use", self.python_path])
+            subprocess.call([self.python_path, "-m", "poetry", "install"])
         
         os.chdir(store_base_path)
 
@@ -545,7 +552,7 @@ class Controller():
 
         # Format launch command with arguments
         cmd = [
-            self._settings.fetch_key('python_path'),
+            f'"{self.python_path}"',
             "-m",
             "poetry",
             "run",
@@ -613,11 +620,21 @@ class Controller():
             else:
                 extensions = f'export KABARET_FLOW_EXT_INSTALLERS="{";".join(extensions)}"'
 
+        # Get job pools
+        pool_names = data_resolve['env'].get("KABARET_JOBS_POOL_NAME", "compositing")
+        pool_var = "JOBS_POOL_NAMES"
+        if platform.system() == "Windows":
+            pool_prompt =  f'set {pool_var}={pool_names}\n'
+            pool_prompt += f'set /p "{pool_var}=Pool(s) (default: {pool_names}): "'
+        else:
+            pool_prompt = f'{pool_var}="{pool_names}"\n'
+            pool_prompt = f'read -p "Pool(s) (default: {pool_names}): {pool_var}"'
+
         # Write main executable
         with open(exec_path, 'w+') as f:
             if platform.system() == "Windows":
                 cmd.append('\ntimeout 30')
-                f.write(f'@echo off\nTitle Libreflow {data_resolve["name"]}\n\n')
+                f.write(f'@echo off\nTitle Libreflow {data_resolve["name"]}\nchcp 1252\n\n')
             else:
                 cmd.append('\nsleep 30')
             
@@ -636,12 +653,12 @@ class Controller():
             sync_cmd = cmd.copy()
 
             if platform.system() == "Windows":
-                f.write(f'@echo off\nTitle Libreflow Sync {data_resolve["name"]}\n\n')
+                f.write(f'@echo off\nTitle Libreflow Sync {data_resolve["name"]}\nchcp 1252\n\n')
             
             f.write(f'{comment_symbol} Project environment variables\n')
             f.write('\n'.join(env_variables))
             
-            sync_cmd[5] = 'libreflow.sync'
+            sync_cmd[6] = 'libreflow.sync'
             sync_cmd.insert(sync_cmd.index('--session'), "--project")
             sync_cmd.insert(
                 sync_cmd.index('--project')+1,
@@ -656,7 +673,7 @@ class Controller():
             jobs_cmd = cmd.copy()
 
             if platform.system() == "Windows":
-                f.write(f'@echo off\nTitle Libreflow Jobs {data_resolve["name"]}\n\n')
+                f.write(f'@echo off\nTitle Libreflow Jobs {data_resolve["name"]}\nchcp 1252\n\n')
             
             f.write(f'{comment_symbol} Project environment variables\n')
             f.write('\n'.join(env_variables))
@@ -665,8 +682,11 @@ class Controller():
                 f.write(f'\n\n{comment_symbol} Flow extensions\n')
                 f.write(extensions)
 
+            f.write(f'\n\n{comment_symbol} Pool names\n')
+            f.write(pool_prompt)
+
             jobs_cmd[6] = 'libreflow.jobs_node'
-            jobs_cmd.insert(7, data_resolve['env'].get("KABARET_JOBS_POOL_NAME", "compositing"))
+            jobs_cmd.insert(7, f"%{pool_var}%" if platform.system() == "Windows" else f"${pool_var}")
             del jobs_cmd[-3:]
 
             if platform.system() == "Windows":
@@ -681,7 +701,7 @@ class Controller():
             index_cmd.insert(len(index_cmd)-1, "--search-auto-indexing")
 
             if platform.system() == "Windows":
-                f.write(f'@echo off\nTitle Libreflow Index {data_resolve["name"]}\n\n')
+                f.write(f'@echo off\nTitle Libreflow Index {data_resolve["name"]}\nchcp 1252\n\n')
             
             f.write(f'{comment_symbol} Project environment variables\n')
             f.write('\n'.join(env_variables))
@@ -699,7 +719,7 @@ class Controller():
                 request_cmd = cmd.copy()
 
                 if platform.system() == "Windows":
-                    f.write(f'@echo off\nTitle Libreflow Request {data_resolve["name"]}\n\n')
+                    f.write(f'@echo off\nTitle Libreflow Request {data_resolve["name"]}\nchcp 1252\n\n')
                 
                 f.write(f'{comment_symbol} Project environment variables\n')
                 f.write('\n'.join(env_variables))
@@ -847,7 +867,7 @@ class Controller():
 
         # If venv exists
         env_info = subprocess.Popen(
-            [self._settings.fetch_key('python_path'), "-m", "poetry", "env", "info"],
+            [self.python_path, "-m", "poetry", "env", "info"],
             stdout=subprocess.PIPE, stderr=subprocess.PIPE,
             universal_newlines=True
         )
@@ -870,7 +890,7 @@ class Controller():
 
         # If all dependencies are installed
         env_deps = subprocess.Popen(
-            [self._settings.fetch_key('python_path'), "-m", "poetry", "show"],
+            [self.python_path, "-m", "poetry", "show"],
             stdout=subprocess.PIPE, stderr=subprocess.PIPE,
             universal_newlines=True
         )
@@ -908,14 +928,14 @@ class Controller():
 
         # Get env name
         env_info = subprocess.Popen(
-            [self._settings.fetch_key('python_path'), "-m", "poetry", "env", "list"],
+            [self.python_path, "-m", "poetry", "env", "list"],
             stdout=subprocess.PIPE, stderr=subprocess.PIPE,
             universal_newlines=True
         )
         env_name = re.search("([^\s]+)", env_info.communicate()[0]).group(0)
 
         # Remove poetry env
-        subprocess.call([self._settings.fetch_key('python_path'), "-m", "poetry", "env", "remove", env_name])
+        subprocess.call([self.python_path, "-m", "poetry", "env", "remove", env_name])
 
         # Back current process to base path
         os.chdir(store_base_path)
